@@ -23,11 +23,10 @@ mod spawn;
 pub use spawn::*;
 
 #[allow(missing_docs)]
-#[cfg(feature = "test_utils")]
+#[cfg(any(test, feature = "test_utils"))]
 pub mod test_util;
 
-#[cfg(test)]
-#[cfg(feature = "test_utils")]
+#[cfg(any(test, feature = "test_utils"))]
 mod test;
 
 pub mod fixt;
