@@ -11,7 +11,6 @@ use crate::*;
 use futures::future::FutureExt;
 use futures::stream::StreamExt;
 use kitsune_p2p_proxy::tx2::*;
-use kitsune_p2p_proxy::ProxyUrl;
 use kitsune_p2p_transport_quic::tx2::*;
 use kitsune_p2p_types::agent_info::AgentInfoSigned;
 use kitsune_p2p_types::async_lazy::AsyncLazy;
@@ -77,7 +76,6 @@ ghost_actor::ghost_chan! {
 }
 
 pub(crate) struct KitsuneP2pActor {
-    this_addr: url2::Url2,
     channel_factory: ghost_actor::actor_builder::GhostActorChannelFactory<Self>,
     internal_sender: ghost_actor::GhostSender<Internal>,
     evt_sender: futures::channel::mpsc::Sender<KitsuneP2pEvent>,
@@ -98,7 +96,7 @@ pub(crate) struct KitsuneP2pActor {
 impl KitsuneP2pActor {
     pub async fn new(
         config: KitsuneP2pConfig,
-        tls_config: kitsune_p2p_proxy::TlsConfig,
+        tls_config: kitsune_p2p_types::tls::TlsConfig,
         channel_factory: ghost_actor::actor_builder::GhostActorChannelFactory<Self>,
         internal_sender: ghost_actor::GhostSender<Internal>,
         evt_sender: futures::channel::mpsc::Sender<KitsuneP2pEvent>,
@@ -149,9 +147,40 @@ impl KitsuneP2pActor {
         let f = if !is_mock {
             let mut conf = kitsune_p2p_proxy::tx2::ProxyConfig::default();
             conf.tuning_params = Some(config.tuning_params.clone());
-            if let Some(use_proxy) = &tx2_conf.use_proxy {
-                let proxy_url = ProxyUrl::from(use_proxy.as_str());
-                conf.client_of_remote_proxy = Some(proxy_url);
+            match tx2_conf.use_proxy {
+                KitsuneP2pTx2ProxyConfig::NoProxy => (),
+                KitsuneP2pTx2ProxyConfig::Specific(proxy_url) => {
+                    conf.client_of_remote_proxy = ProxyRemoteType::Specific(proxy_url);
+                }
+                KitsuneP2pTx2ProxyConfig::Bootstrap {
+                    bootstrap_url,
+                    fallback_proxy_url,
+                } => {
+                    conf.client_of_remote_proxy = ProxyRemoteType::Bootstrap {
+                        bootstrap_url,
+                        fallback_proxy_url,
+                    };
+                    conf.proxy_from_bootstrap_cb = Arc::new(|bootstrap_url| {
+                        Box::pin(async move {
+                            match bootstrap::proxy_list(bootstrap_url.into()).await {
+                                Ok(mut proxy_list) => {
+                                    if proxy_list.is_empty() {
+                                        return None;
+                                    }
+                                    use rand::Rng;
+                                    Some(
+                                        proxy_list
+                                            .remove(
+                                                rand::thread_rng().gen_range(0, proxy_list.len()),
+                                            )
+                                            .into(),
+                                    )
+                                }
+                                _ => None,
+                            }
+                        })
+                    });
+                }
             }
             let f = tx2_proxy(f, conf)?;
             f
@@ -188,10 +217,6 @@ impl KitsuneP2pActor {
         // capture endpoint handle
         let ep_hnd = ep.handle().clone();
 
-        let this_addr = ep_hnd.local_addr().map_err(KitsuneP2pError::other)?;
-
-        tracing::info!("this_addr: {}", this_addr);
-
         let i_s = internal_sender.clone();
         tokio::task::spawn({
             let evt_sender = evt_sender.clone();
@@ -421,7 +446,6 @@ impl KitsuneP2pActor {
         ));
 
         Ok(Self {
-            this_addr: this_addr.into(),
             channel_factory,
             internal_sender,
             evt_sender,
@@ -440,6 +464,9 @@ impl ghost_actor::GhostControlHandler for KitsuneP2pActor {
         use futures::sink::SinkExt;
         use ghost_actor::GhostControlSender;
         async move {
+            // The line below was added when migrating to rust edition 2021, per
+            // https://doc.rust-lang.org/edition-guide/rust-2021/disjoint-capture-in-closures.html#migration
+            let _ = &self;
             // this is a curtesy, ok if fails
             let _ = self.evt_sender.close().await;
             self.ep_hnd.close(500, "").await;
@@ -641,7 +668,7 @@ impl KitsuneP2pEventHandler for KitsuneP2pActor {
     fn handle_gossip(
         &mut self,
         space: Arc<KitsuneSpace>,
-        ops: Vec<(Arc<KitsuneOpHash>, Vec<u8>)>,
+        ops: Vec<KOp>,
     ) -> KitsuneP2pEventHandlerResult<()> {
         Ok(self.evt_sender.gossip(space, ops))
     }
@@ -649,7 +676,7 @@ impl KitsuneP2pEventHandler for KitsuneP2pActor {
     fn handle_fetch_op_data(
         &mut self,
         input: FetchOpDataEvt,
-    ) -> KitsuneP2pEventHandlerResult<Vec<(Arc<KitsuneOpHash>, Vec<u8>)>> {
+    ) -> KitsuneP2pEventHandlerResult<Vec<(Arc<KitsuneOpHash>, KOp)>> {
         Ok(self.evt_sender.fetch_op_data(input))
     }
 
@@ -672,8 +699,8 @@ impl ghost_actor::GhostHandler<KitsuneP2p> for KitsuneP2pActor {}
 
 impl KitsuneP2pHandler for KitsuneP2pActor {
     fn handle_list_transport_bindings(&mut self) -> KitsuneP2pHandlerResult<Vec<url2::Url2>> {
-        let this_addr = vec![self.this_addr.clone()];
-        Ok(async move { Ok(this_addr) }.boxed().into())
+        let this_addr = self.ep_hnd.local_addr();
+        Ok(async move { Ok(vec![this_addr?.into()]) }.boxed().into())
     }
 
     fn handle_join(
@@ -683,7 +710,6 @@ impl KitsuneP2pHandler for KitsuneP2pActor {
     ) -> KitsuneP2pHandlerResult<()> {
         let internal_sender = self.internal_sender.clone();
         let space2 = space.clone();
-        let this_addr = self.this_addr.clone();
         let ep_hnd = self.ep_hnd.clone();
         let config = Arc::clone(&self.config);
         let bandwidth_throttles = self.bandwidth_throttles.clone();
@@ -693,7 +719,6 @@ impl KitsuneP2pHandler for KitsuneP2pActor {
             Entry::Vacant(entry) => entry.insert(AsyncLazy::new(async move {
                 let (send, send_inner, evt_recv) = spawn_space(
                     space2,
-                    this_addr,
                     ep_hnd,
                     config,
                     bandwidth_throttles,
@@ -930,7 +955,7 @@ mockall::mock! {
         fn handle_gossip(
             &mut self,
             space: Arc<KitsuneSpace>,
-            ops: Vec<(Arc<KitsuneOpHash>, Vec<u8>)>,
+            ops: Vec<KOp>,
         ) -> KitsuneP2pEventHandlerResult<()>;
 
         fn handle_query_op_hashes(
@@ -941,7 +966,7 @@ mockall::mock! {
         fn handle_fetch_op_data(
             &mut self,
             input: FetchOpDataEvt,
-        ) -> KitsuneP2pEventHandlerResult<Vec<(Arc<KitsuneOpHash>, Vec<u8>)>> ;
+        ) -> KitsuneP2pEventHandlerResult<Vec<(Arc<KitsuneOpHash>, KOp)>> ;
 
         fn handle_sign_network_data(
             &mut self,
