@@ -83,13 +83,12 @@ async fn test_rpc_multi_logic_mocked() {
     tokio::time::pause();
 
     let space = Arc::new(KitsuneSpace(vec![0; 36]));
-    let this_addr = url2::url2!("fake://");
 
     // build our "SpaceInternal" sender
     let mut m = MockSpaceInternalHandler::new();
     // just make is_agent_local always return false
     m.expect_handle_is_agent_local()
-        .returning(|_| Ok(async move { Ok(false) }.boxed().into()));
+        .returning(|_| ok_fut(Ok(false)));
     let i_s = build_space_internal(m).await;
 
     // build our "KitsuneP2pEvent" sender
@@ -104,8 +103,10 @@ async fn test_rpc_multi_logic_mocked() {
             out.push(A3.clone());
             out.push(A4.clone());
         }
-        Ok(async move { Ok(out) }.boxed().into())
+        ok_fut(Ok(out))
     });
+    m.expect_handle_k_gen_req()
+        .returning(move |_| ok_fut(Ok(KGenRes::RecordMetrics(()))));
     let evt_sender = build_event_handler(m).await;
 
     let config = Arc::new(KitsuneP2pConfig::default());
@@ -240,7 +241,6 @@ async fn test_rpc_multi_logic_mocked() {
     // build up the ro_inner that discover calls expect
     let ro_inner = Arc::new(SpaceReadOnlyInner {
         space: space.clone(),
-        this_addr,
         i_s,
         evt_sender,
         ep_hnd,
